==> neat-python-gicminos-0.95.tar.gz: neat-python-gicminos-0.95/README.md <==
[![Build Status](https://travis-ci.org/Gicminos/neat-python.svg)](https://travis-ci.org/Gicminos/neat-python)
[![Coverage Status](https://coveralls.io/repos/Gicminos/neat-python/badge.svg?branch=master&service=github)](https://coveralls.io/github/Gicminos/neat-python?branch=master)

## STATUS NOTE ##

This project is currently in maintenance-only mode. I will make bug fixes, do cleanup, and possibly improve sample code
as I have time, but I will not be adding any new features.  The forks by
[@drallensmith](https://github.com/drallensmith/neat-python) and [@bennr01](https://github.com/bennr01/neat-python) have
been extended beyond this implementation a great deal, so those might be better starting points if you need more
features than what you see here.

## About ##

NEAT (NeuroEvolution of Augmenting Topologies) is a method developed by Kenneth O. Stanley for evolving arbitrary neural
networks. This project is a pure-Python implementation of NEAT with no dependencies beyond the standard library. It was
forked from the excellent project by @MattKallada, and is in the process of being updated to provide more features and a
(hopefully) simpler and documented API.

For further information regarding general concepts and theory, please see
[Selected Publications](http://www.cs.ucf.edu/~kstanley/#publications) on Stanley's website.

`neat-python` is licensed under the [3-clause BSD license](https://opensource.org/licenses/BSD-3-Clause).

## Getting Started ##

If you want to try neat-python, please check out the repository, start playing with the examples (`examples/xor` is
a good place to start) and then try creating your own experiment.

The documentation, is available on [Read The Docs](http://neat-python.readthedocs.io).

## Citing ##

Here is a Bibtex entry you can use to cite this project in a publication. The listed authors are the maintainers of
all iterations of the project up to this point. 

```
@misc{neat-python,
    Title = {neat-python},
    Author = {Alan McIntyre and Matt Kallada and Cesar G. Miguel and Carolina Feher da Silva},
    howpublished = {\url{https://github.com/CodeReclaimers/neat-python}}   
  }
```

==> neat-python-gicminos-0.96.tar.gz: neat-python-gicminos-0.96/README.md <==
[![Build Status](https://travis-ci.org/Gicminos/neat-python.svg)](https://travis-ci.org/Gicminos/neat-python)
[![Coverage Status](https://coveralls.io/repos/Gicminos/neat-python/badge.svg?branch=master&service=github)](https://coveralls.io/github/Gicminos/neat-python?branch=master)

## FORK STATUS ##

This is a fork from [CodeReclaimers](https://github.com/CodeReclaimers/neat-python). I have been fascinated by the project 
and I started applying some changes and improvement myself but also from the community. I cannot guarantee to push lot of 
new features or fix any issue, but I will do my best to actively check any Pull Request coming in!

## About ##

NEAT (NeuroEvolution of Augmenting Topologies) is a method developed by Kenneth O. Stanley for evolving arbitrary neural
networks. This project is a pure-Python implementation of NEAT with no dependencies beyond the standard library. It was
forked from the excellent project by @MattKallada, and is in the process of being updated to provide more features and a
(hopefully) simpler and documented API.

For further information regarding general concepts and theory, please see
[Selected Publications](http://www.cs.ucf.edu/~kstanley/#publications) on Stanley's website.

`neat-python` is licensed under the [3-clause BSD license](https://opensource.org/licenses/BSD-3-Clause).

## Getting Started ##

If you want to try neat-python, please check out the repository, start playing with the examples (`examples/xor` is
a good place to start) and then try creating your own experiment. Always check the 
[differences between this fork and the main repo](https://github.com/CodeReclaimers/neat-python/compare/master...Gicminos:master)
to decide which one is the more appropriate for your needs.

If you want to use this fork, the PyPi package name is currently `neat-python-gicminos`.

The documentation, is available on [Read The Docs](http://neat-python.readthedocs.io).

## Citing ##

Here is a Bibtex entry you can use to cite this project in a publication. The listed authors are the maintainers of
all iterations of the project up to this point. 

```
@misc{neat-python,
    Title = {neat-python},
    Author = {Alan McIntyre and Matt Kallada and Cesar G. Miguel and Carolina Feher da Silva},
    howpublished = {\url{https://github.com/CodeReclaimers/neat-python}}   
  }
```
